@@ -128,7 +128,6 @@ class QuerySabioOld(query_nosql.DataQuery):
             Return:
                 (:obj:`list` of :obj:`dict`): list of kinlaws that satisfy the condition
         '''
-        result = []
         substrate = 'reaction_participant.substrate_aggregate'
         product = 'reaction_participant.product_aggregate'
         if dof == 0:
@@ -145,7 +144,33 @@ class QuerySabioOld(query_nosql.DataQuery):
         constraint_1 = {product: {'$all': products}}
         query = {'$and': [constraint_0, constraint_1]}
         docs = self.collection.find(filter=query, projection=projection)
-        for doc in docs:
-            result.append(doc)
         count = self.collection.count_documents(query)
-        return count, result
\ No newline at end of file
+        return count, docs
+
+    def get_kinlaw_by_entryid(self, entry_id):
+        """Find reactions by sabio entry id
+        
+        Args:
+            entry_id (:obj:`int`): entry_id
+
+            Return:
+                (:obj:`dict`): {'kinlaw_id': [], 'substrates': [], 'products': []}
+        """
+        result = {}
+        kinlaw_id = []
+        substrates = []
+        products = []
+        constraint_0 = {'namespace': 'sabiork.reaction', 'id': str(entry_id)}
+        query = {'resource': {'$elemMatch': constraint_0}}
+        projection = {'_id': 0, 'kinlaw_id': 1, 'reaction_participant.substrate_aggregate': 1,
+                     'reaction_participant.product_aggregate': 1}
+        docs = self.collection.find(filter=query, projection=projection)
+        for doc in docs:
+            kinlaw_id.append(doc['kinlaw_id'])
+            substrates.append(doc['reaction_participant'][3]['substrate_aggregate'])
+            products.append(doc['reaction_participant'][4]['product_aggregate'])
+
+        result['kinlaw_id'] = kinlaw_id
+        result['substrates'] = substrates
+        result['products'] = products
+        return result
\ No newline at end of file
